@@ -6,7 +6,6 @@ use std::{
 };
 
 use num_bigint::BigInt as BigIntValue;
-use serde::{Deserialize, Serialize};
 use swc_atoms::{js_word, JsWord};
 use swc_common::{ast_node, util::take::Take, EqIgnoreSpan, Span, DUMMY_SP};
 
@@ -132,29 +131,18 @@ impl<'a> arbitrary::Arbitrary<'a> for BigInt {
 }
 
 /// A string literal.
-///
-/// # Note
-///
-/// You have to use [StrKind::Synthesized] if you modify the `value` of [Str].
-/// This behavior is for preserving the original source code.
-///
-/// In other words, `swc_ecma_codegen` tries to preserve escapes or unicode
-/// characters in the original source code and you can opt-out of this by using
-/// [StrKind::Synthesized].
 #[ast_node("StringLiteral")]
-#[derive(Eq, Hash, EqIgnoreSpan)]
+#[derive(Eq, Hash)]
 pub struct Str {
     pub span: Span,
 
     #[cfg_attr(feature = "rkyv", with(crate::EncodeJsWord))]
     pub value: JsWord,
 
-    /// This includes line escape.
-    #[serde(default)]
-    pub has_escape: bool,
-
-    #[serde(default)]
-    pub kind: StrKind,
+    /// Use `None` value only for transformations to avoid recalculate escaped
+    /// characters in strings
+    #[cfg_attr(feature = "rkyv", with(crate::EncodeJsWord))]
+    pub raw: Option<JsWord>,
 }
 
 impl Take for Str {
@@ -162,67 +150,20 @@ impl Take for Str {
         Str {
             span: DUMMY_SP,
             value: js_word!(""),
-            has_escape: Default::default(),
-            kind: Default::default(),
+            raw: None,
         }
     }
 }
 
-/// THis enum determines how string literal should be printed.
-#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Serialize, Deserialize)]
-#[serde(tag = "type")]
-#[cfg_attr(
-    feature = "rkyv",
-    derive(rkyv::Archive, rkyv::Serialize, rkyv::Deserialize)
-)]
-pub enum StrKind {
-    /// Span of string points to original source code, and codegen should use
-    /// it.
-    //
-    /// **Note**: Giving wrong value to this field will result in invalid
-    /// codegen.
-    #[serde(rename = "normal")]
-    Normal {
-        /// Does span of this string literal contains quote?
-        ///
-        /// True for string literals generated by parser, false for string
-        /// literals generated by various passes.
-        #[serde(rename = "containsQuote")]
-        #[cfg_attr(feature = "rkyv", omit_bounds)]
-        contains_quote: bool,
-    },
-    /// If the span of string does not point a string literal, mainly because
-    /// this string is synthesized, this variant should be used.
-    #[serde(rename = "synthesized")]
-    Synthesized,
-}
-
-/// Always returns true as this is not a data of a string literal.
-impl EqIgnoreSpan for StrKind {
-    fn eq_ignore_span(&self, _: &Self) -> bool {
-        true
-    }
-}
-
-impl Default for StrKind {
-    fn default() -> Self {
-        Self::Synthesized
-    }
-}
-
 #[cfg(feature = "arbitrary")]
 #[cfg_attr(docsrs, doc(cfg(feature = "arbitrary")))]
 impl<'a> arbitrary::Arbitrary<'a> for Str {
     fn arbitrary(u: &mut arbitrary::Unstructured<'_>) -> arbitrary::Result<Self> {
         let span = u.arbitrary()?;
         let value = u.arbitrary::<String>()?.into();
+        let raw = Some(u.arbitrary::<String>()?.into());
 
-        Ok(Self {
-            span,
-            value,
-            has_escape: false,
-            kind: Default::default(),
-        })
+        Ok(Self { span, value, raw })
     }
 }
 
@@ -233,6 +174,12 @@ impl Str {
     }
 }
 
+impl EqIgnoreSpan for Str {
+    fn eq_ignore_span(&self, other: &Self) -> bool {
+        self.value == other.value
+    }
+}
+
 /// A boolean literal.
 ///
 ///
@@ -366,8 +313,7 @@ impl From<JsWord> for Str {
         Str {
             span: DUMMY_SP,
             value,
-            has_escape: Default::default(),
-            kind: Default::default(),
+            raw: None,
         }
     }
 }
